@@ -570,6 +570,8 @@ class Preprocessing:
             signal.resample(psgSignal.targetFrequency, antialiaseFIR=False)
         elif stepName == "resampleSimple":
             signal.resample(psgSignal.targetFrequency, simple=True, antialiaseFIR=False)
+        elif stepName == "normalizePercentage70":
+            signal.simpleNormalize(70, 100)
         elif stepName == "normalizePercentage":
             signal.simpleNormalize(0, 100)
         elif stepName == "normalize":
